Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BucketAndObject ¶
type Gcs ¶
type Gcs interface {
Upload(ctx context.Context, params *UploadParams) error
GenerateSignedURL(params *GenerateSignedURLParams) (string, error)
}
type GenerateSignedURLParams ¶
type GenerateSignedURLParams struct {
*BucketAndObject
ExpirationTime time.Time
UploadObjPath string
}
type UploadParams ¶
type UploadParams struct {
LocalObjPath string
UploadObjPath string
*BucketAndObject
}
Directories
¶
| Path | Synopsis |
|---|---|
|
example
|
|
|
generateSignedUrl
command
author: Michael Putong @2024 This is an example on how to implement go-gcs-wrapper to generate a Google Cloud Storage's signedUrl visit the code repository in github.com/michaelwp/go-gcs-wrapper
|
author: Michael Putong @2024 This is an example on how to implement go-gcs-wrapper to generate a Google Cloud Storage's signedUrl visit the code repository in github.com/michaelwp/go-gcs-wrapper |
|
upload
command
|
Click to show internal directories.
Click to hide internal directories.